
dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
dialogStr("Nekaj je spet padlo sem.")

dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
dialogStr("Neke vrste školjka je. Verjetno jo bova morala spet potisniti navzgor po stopnicah.")

dialogId("sch-v-setkani", "font_big", "I can see it now: ‘Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
dialogStr("Zdaj jo lahko vidim: 'Školjka sreča Cvetlični lonec’. To je skoraj tako kot se srečata likalnik in šivalni stroj na operacijski mizi.")

dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
dialogStr("Oprosti, malo me je zaneslo.")

dialogId("sch-m-moc1", "font_small", "Sorry, I was momentarily distracted.")
dialogStr("Žal sem se za trenutek zamotila.")

dialogId("sch-m-moc2", "font_small", "Where I am going with this shell?")
dialogStr("Kam naj grem s to školjko?")
